@@ -1,5 +1,5 @@
 from html import parser, escape
-from typing import Dict, Any, List, Tuple, Set
+from typing import Dict, Any, List, Tuple, Set, Optional
 import re
 import string
 
@@ -96,9 +96,11 @@ class _HTMLParser(parser.HTMLParser):
         self.tag_required_blocklist = required_blocklisted_tags
         self.tag_blocklist = blocklisted_tags
 
-    def handle_starttag(self, tag: str, attrs: List[Tuple[str, str]]):
-        original_tag = self.get_starttag_text()
-        self.__validation_queue.append(original_tag)
+    def handle_starttag(self, tag: str, attrs: List[Tuple[str, Optional[str]]]):
+        # Ignore the type, because mypy is too stupid to infer
+        # that get_starttag_text() can't return None.
+        original_tag = self.get_starttag_text()  # type: ignore
+        self.__validation_queue.append(original_tag)  # type: ignore
 
         if tag in self.tag_blocklist:
             self.__in_dangerous_tag += 1
